# HQ VFX PIPELINE
### Base Libraries Packages for VFX Pipeline

![alt text](https://hqvfx.com/wp-content/uploads/2021/08/site_logo-1.png)


    Base libraries for visual effects content production pipeline
    Copyright (C) 2021  HQ VFX TECHNOLOGIES
    Website: www.hqvfx.com
    Email: contact@hqvfx.com
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
